@@ -227,6 +227,10 @@ def random_ascii_letters_and_digits(p_arg):
     return ba.decode('ascii')
 
 
+# 返回一个自增长序列
+# 有1个参数：
+#   start   即自正常序列的开始值
+#   步长目前没有支持，都是1
 def identity(p_arg):
     nStart = int(p_arg[0])
     if not hasattr(identity, 'x'):
@@ -236,12 +240,12 @@ def identity(p_arg):
     return str(identity.x)
 
 
-# 返回一个时间戳
+# 返回一个自增长的时间戳
 # 有3个参数：
 #   stime   开始时间
-#     若stime为current_timestamp, 则表示当前时间
+#     若stime写作current_timestamp, 则自增上从当前时间开始
 #   frmt    日期格式，可以忽略，默认为%Y-%m-%d %H:%M:%S
-#   step    步长
+#   step    步长，可以用ms,us,s来表示，默认情况下是ms
 def identity_timestamp(p_arg):
     if len(p_arg) == 2:
         ptime = str(p_arg[0])
@@ -259,19 +263,25 @@ def identity_timestamp(p_arg):
         if ptime == "current_timestamp":
             identity_timestamp.x = datetime.datetime.now()
         else:
-            print("here is time...")
             identity_timestamp.x = datetime.datetime.strptime(ptime, frmt)
     else:
         # 判断步长单位，默认是毫秒，可以是s,ms
-        if step.endswith("ms"):
-            identity_timestamp.x = (identity_timestamp.x + datetime.timedelta(milliseconds=int(step[:-2])))
-        elif step.endswith("s"):
-            identity_timestamp.x = (identity_timestamp.x + datetime.timedelta(seconds=int(step[:-1])))
+        if step.endswith("s"):
+            if step.endswith("ms"):
+                # end with ms 毫秒
+                identity_timestamp.x = (identity_timestamp.x + datetime.timedelta(milliseconds=float(step[:-2])))
+            elif step.endswith("us"):
+                # end with us 微妙
+                identity_timestamp.x = (identity_timestamp.x + datetime.timedelta(microseconds=float(step[:-2])))
+            else:
+                # end with s 秒
+                identity_timestamp.x = (identity_timestamp.x + datetime.timedelta(seconds=float(step[:-1])))
         else:
-            identity_timestamp.x = (identity_timestamp.x + datetime.timedelta(milliseconds=int(step)))
+            identity_timestamp.x = (identity_timestamp.x + datetime.timedelta(milliseconds=float(step)))
     return identity_timestamp.x.strftime(frmt)
 
 
+# 将传递的SQL字符串转换成一个带有函数指针的数组
 def parse_formula_str(p_formula_str):
     m_row_struct = re.split('[{}]', p_formula_str)
     m_return_row_struct = []
